@@ -4,8 +4,8 @@ import shutil
 
 import h5py
 import scipy.sparse
+from himalaya.progress_bar import ProgressBar
 
-from .progress_bar import ProgressBar
 
 URL_CRCNS = 'https://portal.nersc.gov/project/crcns/download/index.php'
 
@@ -114,12 +114,14 @@ def download_datalad(datafile, destination, source,
     --------
     >>> from voxelwise_tutorials.io import get_data_home
     >>> from voxelwise_tutorials.io import download_datalad
-    >>> directory = get_data_home(dataset="shortclips")
-    >>> download_datalad("features/wordnet.hdf", destination=directory,
+    >>> destination = get_data_home(dataset="shortclips")
+    >>> download_datalad("features/wordnet.hdf", destination=destination,
                          source="https://gin.g-node.org/gallantlab/shortclips")
     """
     import datalad.api
-    dataset = datalad.api.install(path=destination, source=source)
+    dataset = datalad.api.Dataset(path=destination)
+    if not dataset.is_installed():
+        dataset = datalad.api.install(path=destination, source=source)
 
     def has_content():
         """Double check that the file is actually present."""
@@ -207,14 +209,6 @@ OLD_KEYS = {
 }
 
 
-def _concatenate_fsaverage_left_right(file_name):
-    """Load the"""
-    voxel_to_fsavg_L = load_hdf5_sparse_array(file_name, "vox_to_fsavg_left")
-    voxel_to_fsavg_R = load_hdf5_sparse_array(file_name, "vox_to_fsavg_right")
-    voxel_to_fsavg = scipy.sparse.vstack([voxel_to_fsavg_L, voxel_to_fsavg_R])
-    return voxel_to_fsavg
-
-
 def save_hdf5_dataset(file_name, dataset, mode='w'):
     """Save a dataset of arrays and sparse arrays.
 
